@@ -320,21 +320,16 @@ class NewsletterControllerMailinglist extends Hubzero_Controller
 		$currentEmails = array_keys($newsletterMailinglist->getListEmails( $this->mid, $key ='email', $filters ));
 		
 		//get the applicaton
-		$application = JFactory::getApplication();
+		$application =& JFactory::getApplication();
 		
 		//get com_media params
-		$config = JComponentHelper::getParams('com_media');
+		$config =& JComponentHelper::getParams('com_media');
 		
 		//array of allowed extensions
 		$allowedExtensions = array('txt','csv','xls','xlsx');
 		
 		//max file size
-		$maxFileSize = (int) $config->get('upload_maxsize');
-		
-		if (version_compare(JVERSION, '1.6', 'ge'))
-		{
-			$maxFileSize = $maxFileSize * 1024 * 1024;
-		}
+		$maxFileSize = $config->get('upload_maxsize');
 		
 		//if we have a file
 		if (isset($this->emailFile['size']) && $this->emailFile['size'] > 0)
@@ -405,7 +400,7 @@ class NewsletterControllerMailinglist extends Hubzero_Controller
 			}
 			else
 			{
-				$inserts[] = "(" . $this->mid . ", '" . $email . "', 'active', 0, '".JFactory::getDate()->toSql()."')";
+				$inserts[] = "(" . $this->mid . ", '" . $email . "', 'active', 0, '".date("Y-m-d H:i:s")."')";
 			}
 		}
 		
@@ -646,7 +641,7 @@ class NewsletterControllerMailinglist extends Hubzero_Controller
 		$emails = $newsletterMailinglist->getListEmails( $id, null, array('status' => 'all') );
 		
 		//file name
-		$filename = 'Newsletter Mailing List Export - ' . $newsletterMailinglist->name . ' - ' . JFactory::getDate()->format('m-d-Y') . '.csv';
+		$filename = 'Newsletter Mailing List Export - ' . $newsletterMailinglist->name . ' - ' . date('m-d-Y') . '.csv';
 		
 		//file contents
 		$content = 'Email, Status' . PHP_EOL;
