@@ -68,7 +68,7 @@ class BlogControllerEntries extends Hubzero_Controller
 	 */
 	protected function _buildPathway()
 	{
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 
 		$title = ($this->config->get('title')) ? $this->config->get('title') : JText::_(strtoupper($this->_option));
 
@@ -143,7 +143,7 @@ class BlogControllerEntries extends Hubzero_Controller
 				$this->_title .= ': ' . stripslashes($this->view->row->get('title'));
 			}
 		}
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->_title);
 	}
 
@@ -165,11 +165,7 @@ class BlogControllerEntries extends Hubzero_Controller
 		$this->view->filters['start']    = JRequest::getInt('limitstart', 0);
 		$this->view->filters['year']     = JRequest::getInt('year', 0);
 		$this->view->filters['month']    = JRequest::getInt('month', 0);
-		$this->view->filters['scope']    = $this->config->get('show_from', 'site');
-		if ($this->view->filters['scope'] == 'both')
-		{
-			$this->view->filters['scope'] = '';
-		}
+		$this->view->filters['scope']    = 'site';
 		$this->view->filters['group_id'] = 0;
 		$this->view->filters['search']   = JRequest::getVar('search', '');
 		$this->view->filters['authorized'] = false;
@@ -432,14 +428,8 @@ class BlogControllerEntries extends Hubzero_Controller
 			return;
 		}
 
-		// Check for request forgeries
-		JRequest::checkToken() or jexit('Invalid Token');
-
 		$entry = JRequest::getVar('entry', array(), 'post', 'none', 2);
-		
-		// make sure we dont want to turn off comments
-		$entry['allow_comments'] = (isset($entry['allow_comments'])) ? : 0;
-		
+
 		$row = $this->model->entry(0);
 
 		if (!$row->bind($entry)) 
@@ -537,9 +527,6 @@ class BlogControllerEntries extends Hubzero_Controller
 			return;
 		}
 
-		// Check for request forgeries
-		JRequest::checkToken() or jexit('Invalid Token');
-
 		// Delete the entry itself
 		$entry->set('state', -1);
 		if (!$entry->store()) 
@@ -572,7 +559,7 @@ class BlogControllerEntries extends Hubzero_Controller
 		include_once(JPATH_ROOT . DS . 'libraries' . DS . 'joomla' . DS . 'document' . DS . 'feed' . DS . 'feed.php');
 
 		// Set the mime encoding for the document
-		$jdoc = JFactory::getDocument();
+		$jdoc =& JFactory::getDocument();
 		$jdoc->setMimeEncoding('application/rss+xml');
 
 		// Start a new feed object
@@ -655,6 +642,17 @@ class BlogControllerEntries extends Hubzero_Controller
 	 */
 	public function savecommentTask()
 	{
+		$yearFormat = '%Y';
+		$monthFormat = '%m';
+		$tz = 0;
+
+		if (version_compare(JVERSION, '1.6', 'ge'))
+		{
+		       $yearFormat = 'Y';
+		       $monthFormat = 'm';
+		       $tz = null;
+		}
+
 		// Ensure the user is logged in
 		if ($this->juser->get('guest')) 
 		{
@@ -667,9 +665,6 @@ class BlogControllerEntries extends Hubzero_Controller
 			return;
 		}
 
-		// Check for request forgeries
-		JRequest::checkToken() or jexit('Invalid Token');
-
 		// Incoming
 		$comment = JRequest::getVar('comment', array(), 'post');
 
@@ -691,11 +686,11 @@ class BlogControllerEntries extends Hubzero_Controller
 		/*
 		if ($row->get('created_by') != $this->member->get('uidNumber)) 
 		{
-			$this->entry = new BlogTableEntry($this->database);
+			$this->entry = new BlogEntry($this->database);
 			$this->entry->load($row->entry_id);
 			
 			// Get the site configuration
-			$jconfig = JFactory::getConfig();
+			$jconfig =& JFactory::getConfig();
 
 			// Build the "from" data for the e-mail
 			$from = array();
@@ -705,7 +700,7 @@ class BlogControllerEntries extends Hubzero_Controller
 			$subject = JText::_('PLG_MEMBERS_BLOG_SUBJECT_COMMENT_POSTED');
 
 			// Build the SEF referenced in the message
-			$juri = JURI::getInstance();
+			$juri =& JURI::getInstance();
 			$sef = JRoute::_('index.php?option='.$this->option.'&id='. $this->member->get('uidNumber').'&active=blog&task='.JHTML::_('date',$this->entry->publish_up, $yearFormat, $tz).'/'.JHTML::_('date',$this->entry->publish_up, $monthFormat, $tz).'/'.$this->entry->alias.'#comments);
 			if (substr($sef,0,1) == '/') {
 				$sef = substr($sef,1,strlen($sef));
@@ -719,7 +714,7 @@ class BlogControllerEntries extends Hubzero_Controller
 
 			// Send the message
 			JPluginHelper::importPlugin('xmessage');
-			$dispatcher = JDispatcher::getInstance();
+			$dispatcher =& JDispatcher::getInstance();
 			if (!$dispatcher->trigger('onSendMessage', array('blog_comment', $subject, $message, $from, array($this->member->get('uidNumber')), $this->option))) {
 				$this->setError(JText::_('PLG_MEMBERS_BLOG_ERROR_MSG_MEMBER_FAILED'));
 			}
@@ -751,7 +746,7 @@ class BlogControllerEntries extends Hubzero_Controller
 		}
 
 		// Initiate a blog comment object
-		$comment = new BlogTableComment($this->database);
+		$comment = new BlogComment($this->database);
 		$comment->load($id);
 
 		if ($this->juser->get('id') != $comment->created_by && !$this->config->get('access-manage-entry')) 
@@ -794,7 +789,7 @@ class BlogControllerEntries extends Hubzero_Controller
 		include_once(JPATH_ROOT . DS . 'libraries' . DS . 'joomla' . DS . 'document' . DS . 'feed' . DS . 'feed.php');
 
 		// Set the mime encoding for the document
-		$jdoc = JFactory::getDocument();
+		$jdoc =& JFactory::getDocument();
 		$jdoc->setMimeEncoding('application/rss+xml');
 
 		// Start a new feed object
@@ -821,7 +816,7 @@ class BlogControllerEntries extends Hubzero_Controller
 		$month = JRequest::getInt('month', 0);
 
 		// Build some basic RSS document information
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 		$doc->title  = $jconfig->getValue('config.sitename') . ' - ' . JText::_(strtoupper($this->_option));
 		$doc->title .= ($year) ? ': ' . $year : '';
 		$doc->title .= ($month) ? ': ' . sprintf("%02d", $month) : '';
