@@ -15,20 +15,14 @@ function get_conf($db_id)
 {
 	global $dv_conf, $com_name;
 
-	$params = JComponentHelper::getParams('com_datastores');
+	$params = &JComponentHelper::getParams('com_datastores');
 	$dv_conf['db']['host'] = $params->get('db_host');
 	$dv_conf['db']['user'] = $params->get('db_ro_user');
 	$dv_conf['db']['password'] = $params->get('db_ro_pass');
 
 	$dv_conf['db']['database'] = 'ds_' . $db_id['name'];
 
-	// DataStores base directory
-	$ds_base_dir = $params->get('base_dir');
-	if ($ds_base_dir == '') {
-		$ds_base_dir = '/data/datastores'; // Switch the default to /db when it's created
-	}
-
-	$dv_conf['base_path'] = $ds_base_dir . '/' . $db_id['name'];
+	$dv_conf['base_path'] = '/data/datastores/' . $db_id['name'];
 
 	return $dv_conf;
 }
@@ -37,7 +31,7 @@ function get_dd($db_id)
 {
 	global $dv_conf;
 	$dd = false;
-	$db = JFactory::getDBO();
+	$db = &JFactory::getDBO();
 
 	$dv_id = JRequest::getVar('dv');
 
@@ -53,22 +47,7 @@ function get_dd($db_id)
 		$dd['table'] = $td['name'];
 		$dd['title'] = $r['name'];
 
-		if (isset($db_id['extra']) && ($db_id['extra'] == 'table' || $db_id['extra'] == 'update')) {
-
-			if ($db_id['extra'] == 'update') {
-				$update_link = '/datastores/' . $db_id['name'] . '/table/data_record_update/?table=' . $dv_id . '&__ds_rec_id=';
-
-				$dd['cols'][$td['name'] . '.__ds_rec_id'] = array(
-					'label'=>'Select <br />Record',
-					'raw'=>"CONCAT('$update_link', __ds_rec_id)",
-					'type'=>'link',
-					'relative'=>'true',
-					'link_label'=>'Edit',
-					'link_title'=>'Click here to update or remove this record',
-					'popup'=>array('window'=>'Edit_Record', 'features'=>'width=1175px,resizable,scrollbars,status')
-				);
-			}
-
+		if ($db_id['extra'] == 'table') {
 			foreach($td['columns'] as $col) {
 				if ($col['name'] != '__ds_rec_id') {
 					if ($col['type'] == 'file') {
@@ -78,9 +57,33 @@ function get_dd($db_id)
 						$dd['cols'][$td['name'] . '.' . $col['name']]['file-verify'] = true;
 					}
 
-					if ($col['type'] == 'url') {
-						$dd['cols'][$td['name'] . '.' . $col['name']]['type'] = 'url';
-						$dd['cols'][$td['name'] . '.' . $col['name']]['url-display'] = 'full_link';
+					if ($col['type'] == 'txt' && ($col['type_extra'] == 'medium' || $col['type_extra'] == 'large')) {
+						$dd['cols'][$td['name'] . '.' . $col['name']]['width'] = '150';
+						$dd['cols'][$td['name'] . '.' . $col['name']]['truncate'] = 'truncate';
+					}
+
+					$dd['cols'][$td['name'] . '.' . $col['name']]['label'] = $col['label'];
+				}
+			}
+		} elseif ($db_id['extra'] == 'update') {
+			$update_link = '/datastores/' . $db_id['name'] . '/table/data_record_update/?table=' . $dv_id . '&__ds_rec_id=';
+
+			$dd['cols'][$td['name'] . '.__ds_rec_id'] = array(
+				'label'=>'Select <br />Record',
+				'raw'=>"CONCAT('$update_link', __ds_rec_id)",
+				'type'=>'link',
+				'relative'=>'true',
+				'link_label'=>'Edit',
+				'link_title'=>'Click here to update or remove this record'
+			);
+
+			foreach($td['columns'] as $col) {
+				if ($col['name'] != '__ds_rec_id') {
+					if ($col['type'] == 'file') {
+						$dd['cols'][$td['name'] . '.' . $col['name']]['type'] = 'file';
+						$dd['cols'][$td['name'] . '.' . $col['name']]['type_extra'] = $col['type_extra'];
+						$dd['cols'][$td['name'] . '.' . $col['name']]['ds-repo-path'] = "/file_repo/{$td['name']}/{$col['name']}";
+						$dd['cols'][$td['name'] . '.' . $col['name']]['file-verify'] = true;
 					}
 
 					if ($col['type'] == 'txt' && ($col['type_extra'] == 'medium' || $col['type_extra'] == 'large')) {
@@ -94,53 +97,31 @@ function get_dd($db_id)
 		}
 	} else {
 		$dsid = $db_id['name'];
-		$path = "{$dv_conf['base_path']}/datadefinitions";
+		$path = "/data/datastores/$dsid/datadefinitions";
 		$dd_file = "$dv_id.json";
-		if(file_exists("$path/$dd_file")) {
-			$dd = json_decode(file_get_contents("$path/$dd_file"), true);
-		} else {
-			return false;
-		}
+		$dd = json_decode(file_get_contents("$path/$dd_file"), true);
 	}
 	
-
+	
 	
 	$dd['db_id'] = $db_id;
 	$dd['dv_id'] = $dv_id;
 
 	$dd = _dd_post($dd);
 
-	$dd['conf'] = (isset($dd['conf'])) ? $dd['conf'] : array();
-
-	if(isset($dd['conf']['proc_mode_switch'])) {
-		$dv_conf['proc_mode_switch'] = $dd['conf']['proc_mode_switch'];
-	}
-
-	if(isset($dd['conf']['proc_switch_threshold'])) {
-		$dv_conf['proc_switch_threshold'] = $dd['conf']['proc_switch_threshold'];
-	}
 
 	/* Dynamically set processing mode */
-	if (isset($dv_conf['proc_mode_switch']) && $dv_conf['proc_mode_switch']) {
-		$link = get_db();
-		$total = mysql_query(query_gen_total($dd), $link);
-		if ($total) {
-			$total = mysql_fetch_assoc($total);
-			$total = isset($total['total']) ? $total['total'] : 0;
-			$dd['total_records'] = $total;
+	$link = get_db($dd['db']);
+	$cell_count_threshold = 20000;
+	$total = mysql_query(query_gen_total($dd), $link);
+	$total = mysql_fetch_assoc($total);
+	$total = isset($total['total']) ? $total['total'] : 0;
+	$dd['total_records'] = $total;
 
-			$vis_col_count = 0;
-			if(isset($dd['cols'])) {
-				$vis_col_count = count(array_filter($dd['cols'], function ($col) {
-						return !isset($col['hide']); 
-					})
-				);
-			}
+	$vis_col_count = count(array_filter($dd['cols'], function ($col) { return !isset($col['hide']); }));
 
-			if ($dv_conf['proc_switch_threshold'] < ($total * $vis_col_count)) {
-				$dd['serverside'] = true;
-			}
-		}
+	if ($cell_count_threshold < ($total * $vis_col_count)) {
+		$dd['serverside'] = true;
 	}
 
 
@@ -178,29 +159,7 @@ function get_dd($db_id)
 
 
 	/* ACL */
-
-	// Dataviews attached to resources & publised
-	$sql = "SELECT r.id, r.published, r.access, r.group_owner, r.group_access, dv.path 
-		FROM jos_datastore_resources AS dr 
-			LEFT JOIN (jos_resources AS r, jos_resource_assoc ra, jos_resources AS dv) ON (r.id = dr.resource_id AND ra.parent_id = r.id AND ra.child_id = dv.id) 
-		WHERE r.id IS NOT NULL 
-			AND r.published = 1 
-			AND dr.datastore_id = {$db_id['name']} 
-			AND dv.path = '/dataviewer/view/{$db_id['name']}:ds/$dv_id/'";
-	$db->setQuery($sql);
-	$res = $db->loadAssoc();
-
-	if (isset($res['id'])) {
-		$dd['acl'] = array();
-
-		// Public
-		if ($res['access'] == 0) {
-			$dd['acl']['public'] = true;
-		}
-	}
-
-	//$sql = 'SELECT username FROM #__datastores ds LEFT JOIN #__users u ON (u.id = ds.created_by)';
-	$sql = "SELECT username FROM #__datastore_users ds LEFT JOIN #__users u ON (u.id = ds.value AND ds.type='user') WHERE ds.id = " . $db_id['name'];
+	$sql = 'SELECT username FROM #__datastores ds LEFT JOIN #__users u ON (u.id = ds.created_by)';
 	$db->setQuery($sql);
 	$managers = $db->loadResultArray();
 
@@ -211,13 +170,6 @@ function get_dd($db_id)
 		$dd['acl']['allowed_users'] = array_merge($dd['acl']['allowed_users'], $managers);
 	}
 
-	// Giving Hub admins full access to the DataStore dataviews
-	$juser = JFactory::getUser();
-	if ($juser->get('usertype') == 'Super Administrator' || $juser->get('usertype') == 'Administrator' || $juser->get('usertype') == 'Manager' ) {
-		$dd['acl']['allowed_users'] = isset($dd['acl']['allowed_users']) ? $dd['acl']['allowed_users'] : array();
-		$dd['acl']['allowed_users'][] = $juser->get('username');
-	}
-
 	return $dd;
 }
 
@@ -238,10 +190,8 @@ function _dd_post($dd)
 	}
 
 	// Data for Custom Views
-	$custom_view = JRequest::getVar('custom_view', '');
-
-	if ($custom_view != '') {
-		$custom_view = explode(',', $custom_view);
+	$custom_view = JRequest::getVar('custom_view', array());
+	if (count($custom_view) > 0) {
 		unset($dd['customizer']);
 
 		// Custom Title
@@ -283,11 +233,11 @@ function pathway($dd)
 {
 	$db_id = $dd['db_id'];
 
-	$document = JFactory::getDocument();
+	$document = &JFactory::getDocument();
 	$document->setTitle($dd['title']);
 
-	$mainframe = JFactory::getApplication();
-	$pathway = $mainframe->getPathway();
+	$mainframe = &JFactory::getApplication();
+	$pathway = &$mainframe->getPathway();
 
 	if (isset($db_id['extra']) && $db_id['extra'] == 'table') {
 		$ref_title = "Datastore";
